@@ -1,4 +1,5 @@
 """Command to call or invoke StarkNet smart contracts."""
+import logging
 import os
 import subprocess
 
@@ -6,7 +7,9 @@ from nile import deployments
 from nile.common import GATEWAYS
 
 
-def call_or_invoke(contract, type, method, params, network, signature=None):
+def call_or_invoke(
+    contract, type, method, params, network, signature=None, max_fee=None
+):
     """Call or invoke functions of StarkNet smart contracts."""
     address, abi = next(deployments.load(contract, network))
 
@@ -37,4 +40,24 @@ def call_or_invoke(contract, type, method, params, network, signature=None):
         command.append("--signature")
         command.extend(signature)
 
-    return subprocess.check_output(command).strip().decode("utf-8")
+    if max_fee is not None:
+        command.append("--max_fee")
+        command.append(max_fee)
+
+    try:
+        output = subprocess.check_output(command).strip().decode("utf-8")
+        return output
+
+    except subprocess.CalledProcessError:
+        p = subprocess.Popen(command, stderr=subprocess.PIPE)
+        _, error = p.communicate()
+
+        if "max_fee must be bigger than 0" in error.decode():
+            logging.error(
+                """
+                \n😰 Whoops, looks like max fee is missing. Try with:\n
+                --max_fee=`MAX_FEE`
+                """
+            )
+        else:
+            raise
